# Weights and Biases

[![ci](https://circleci.com/gh/wandb/client.svg?style=svg)](https://circleci.com/gh/wandb/client) [![pypi](https://img.shields.io/pypi/v/wandb.svg)](https://pypi.python.org/pypi/wandb) [![coveralls](https://coveralls.io/repos/github/wandb/client/badge.svg?branch=master)](https://coveralls.io/github/wandb/client?branch=master)

A CLI and library for interacting with the Weights and Biases API.  Sign up for an account at [wandb.ai](https://wandb.ai)

## Features

* Keep a history of your weights and models from every training run
* Store all configuration parameters used in a training run
* Associate version control with your training runs
* Search and visualize training runs in a project

## Usage

Detailed usage can be found in our [documentation](http://wb-client.readthedocs.io/).
